@@ -7,13 +7,13 @@ import (
 //go:embed scripts/omp.elv
 var elvishInit string
 
-func (f Feature) Elvish() Code {
+func (f Features) Elvish() Code {
 	switch f {
 	case Upgrade:
-		return "$_omp_executable upgrade"
+		return "$_omp_executable upgrade --auto"
 	case Notice:
 		return "$_omp_executable notice"
-	case PromptMark, RPrompt, PoshGit, Azure, LineError, Jobs, CursorPositioning, Tooltips, Transient, FTCSMarks:
+	case PromptMark, RPrompt, PoshGit, Azure, LineError, Jobs, CursorPositioning, Tooltips, Transient, FTCSMarks, Async:
 		fallthrough
 	default:
 		return ""
